==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggpagemain.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggpagemain.h"


#include "iggmainwindow.h"


iggPageMain::iggPageMain(iggFrameBase *parent, bool withbook) : iggPage(parent,withbook)
{
	mFlipFrame = 0;
	mFlipIndex = -1;
}


iggPageMain::~iggPageMain()
{
}


void iggPageMain::UpdateChildren()
{
	if(mFlipFrame == 0)
	{
		//
		//  Attach a flip frame
		//
		mFlipFrame = this->CreateFlipFrame(this->GetMainWindow()->GetDataTypeFrame());
		mFlipIndex = this->GetMainWindow()->GetDataTypeFrame()->Count();
		this->GetMainWindow()->GetDataTypeFrame()->AddLayer(mFlipFrame);
	}

	mFlipFrame->UpdateWidget();
	iggPage::UpdateChildren();
	if(this->IsVisible()) this->GetMainWindow()->GetDataTypeFrame()->ShowLayer(mFlipIndex);
}

==> ifrit_3.1.5.orig.tar.gz: ifrit-3.1.5/shells/generic/iggpagemain.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggpagemain.h"


#include "iggmainwindow.h"


iggPageMain::iggPageMain(iggFrameBase *parent, bool withbook, bool feedback) : iggPage(parent,withbook,feedback)
{
	mFlipFrame = 0;
	mFlipIndex = -1;
}


iggPageMain::~iggPageMain()
{
}


void iggPageMain::Polish()
{
	if(mFlipFrame == 0)
	{
		//
		//  Attach a flip frame
		//
		mFlipFrame = this->CreateFlipFrame(this->GetMainWindow()->GetDataTypeFrame());
		mFlipIndex = this->GetMainWindow()->GetDataTypeFrame()->Count();
		this->GetMainWindow()->GetDataTypeFrame()->AddLayer(mFlipFrame);
	}
}


void iggPageMain::UpdateChildren()
{
	this->Polish();

	mFlipFrame->UpdateWidget();
	iggPage::UpdateChildren();
	if(this->IsVisible()) this->GetMainWindow()->GetDataTypeFrame()->ShowLayer(mFlipIndex);
}
